summaryrefslogtreecommitdiff
path: root/jasper.py
diff options
context:
space:
mode:
authorschneefux <schneefux+commit@schneefux.xyz>2014-09-19 12:30:29 +0200
committerschneefux <schneefux+commit@schneefux.xyz>2014-09-19 12:30:29 +0200
commit3934c771b944e30e278f53be4480c6e5d24643bc (patch)
tree585b2d90030548204cab1d47863fc67ef4a47f97 /jasper.py
parent259c5798024d3a4136d55e6ffd2035b46df98fcb (diff)
downloadjasper-client-3934c771b944e30e278f53be4480c6e5d24643bc.tar.gz
jasper-client-3934c771b944e30e278f53be4480c6e5d24643bc.zip
Replace JASPER_HOME with jasperpath.APP_PATH + os.pardir
Diffstat (limited to 'jasper.py')
-rwxr-xr-xjasper.py19
1 files changed, 7 insertions, 12 deletions
diff --git a/jasper.py b/jasper.py
index 346617f..62713ee 100755
--- a/jasper.py
+++ b/jasper.py
@@ -10,12 +10,8 @@ logger = logging.getLogger(__name__)
import yaml
import argparse
-# Set $JASPER_HOME
-if not os.getenv('JASPER_HOME'):
- os.environ["JASPER_HOME"] = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
-
from client.diagnose import Diagnostics
-from client import vocabcompiler, stt
+from client import vocabcompiler, stt, jasperpath
from client import speaker as speak
from client.conversation import Conversation
@@ -33,16 +29,15 @@ if args.local:
else:
from client.mic import Mic
-# Change CWD to $JASPER_HOME/jasper/client
-client_path = os.path.join(os.getenv("JASPER_HOME"), "jasper", "client")
-os.chdir(client_path)
-# Add $JASPER_HOME/jasper/client to sys.path
-sys.path.append(client_path)
+# Change CWD to jasperpath.LIB_PATH
+os.chdir(jasperpath.LIB_PATH)
+# Add jasperpath.LIB_PATH to sys.path
+sys.path.append(jasperpath.LIB_PATH)
class Jasper(object):
def __init__(self):
# Read config
- config_file = os.path.abspath(os.path.join(client_path, 'profile.yml'))
+ config_file = os.path.abspath(os.path.join(jasperpath.LIB_PATH, 'profile.yml'))
logger.debug("Trying to read config file: '%s'", config_file)
with open(config_file, "r") as f:
self.config = yaml.safe_load(f)
@@ -59,7 +54,7 @@ class Jasper(object):
logger.warning("stt_engine not specified in profile, defaulting to '%s'", stt_engine_type)
# Compile dictionary
- sentences, dictionary, languagemodel = [os.path.abspath(os.path.join(client_path, filename)) for filename in ("sentences.txt", "dictionary.dic", "languagemodel.lm")]
+ sentences, dictionary, languagemodel = [os.path.abspath(os.path.join(jasperpath.LIB_PATH, filename)) for filename in ("sentences.txt", "dictionary.dic", "languagemodel.lm")]
vocabcompiler.compile(sentences, dictionary, languagemodel)
# Initialize Mic